pub enum FeatureFactoryError {
IoError(Error),
DataFusionError(DataFusionError),
ArrowError(ArrowError),
ParquetError(ParquetError),
InvalidParameter(String),
UnsupportedFormat(String),
NotImplemented(String),
MissingColumn(String),
FitNotCalled,
}Expand description
Errors specific to the Feature Factory library.
Variants
IoError(Error)
Wraps underlying I/O errors.
DataFusionError(DataFusionError)
Wraps errors from DataFusion.
ArrowError(ArrowError)
Wraps errors from Arrow.
ParquetError(ParquetError)
Wraps errors from Parquet.
InvalidParameter(String)
Indicates that an invalid parameter was provided (e.g., unsupported value or incorrect data type).
UnsupportedFormat(String)
Indicates that the provided data format is unsupported (e.g., unknown file format).
NotImplemented(String)
Indicates a feature or functionality has not yet been implemented.
MissingColumn(String)
Indicates that the specified column does not exist in the DataFrame.
FitNotCalled
Indicates the transform method was called before calling fit for a stateful transformer.