pub struct DatetimeFeatures {
pub columns: Vec<String>,
}Expand description
Extracts features from datetime columns.
For each column in self.columns, it adds the following new features:
<column>_year, <column>_month, <column>_day, <column>_hour,
<column>_minute, <column>_second, and <column>_weekday.
Fields
columns: Vec<String>Implementations
Sourceimpl DatetimeFeatures
impl DatetimeFeatures
pub fn new(columns: Vec<String>) -> Self
Sourcepub async fn fit(&mut self, _df: &DataFrame) -> FeatureFactoryResult<()>
pub async fn fit(&mut self, _df: &DataFrame) -> FeatureFactoryResult<()>
Stateless transformer: fit does nothing.
Sourcepub fn transform(&self, df: DataFrame) -> FeatureFactoryResult<DataFrame>
pub fn transform(&self, df: DataFrame) -> FeatureFactoryResult<DataFrame>
Transform validates that each target column exists and is a datetime type, then returns a new DataFrame with the additional extracted features.