pub struct DatetimeSubtraction {
pub new_features: Vec<(String, String, String, TimeUnit)>,
}Expand description
Computes time differences between two datetime columns.
new_features is a list of tuples: (new_feature_name, left_column, right_column, time_unit).
Transform validates that each left and right column exists and is of a datetime type.
Fields
new_features: Vec<(String, String, String, TimeUnit)>Implementations
Sourceimpl DatetimeSubtraction
impl DatetimeSubtraction
pub fn new(new_features: Vec<(String, String, String, TimeUnit)>) -> Self
Sourcepub async fn fit(&mut self, _df: &DataFrame) -> FeatureFactoryResult<()>
pub async fn fit(&mut self, _df: &DataFrame) -> FeatureFactoryResult<()>
Stateless transformer: fit does nothing.
Sourcepub fn transform(&self, df: DataFrame) -> FeatureFactoryResult<DataFrame>
pub fn transform(&self, df: DataFrame) -> FeatureFactoryResult<DataFrame>
Transform validates that each left and right column exists and is a datetime type, then adds a new column for each specified time difference.