pub struct ArbitraryDiscretizer {
pub columns: Vec<String>,
pub intervals: HashMap<String, Vec<(f64, f64, String)>>,
}Expand description
Discretizes a column into arbitrary intervals defined by the user.
Fields
columns: Vec<String>intervals: HashMap<String, Vec<(f64, f64, String)>>Implementations
Sourceimpl ArbitraryDiscretizer
impl ArbitraryDiscretizer
pub fn new( columns: Vec<String>, intervals: HashMap<String, Vec<(f64, f64, String)>>, ) -> Self
Sourcepub async fn fit(&mut self, _df: &DataFrame) -> FeatureFactoryResult<()>
pub async fn fit(&mut self, _df: &DataFrame) -> FeatureFactoryResult<()>
Stateless transformer: fit does nothing.
Sourcepub fn transform(&self, df: DataFrame) -> FeatureFactoryResult<DataFrame>
pub fn transform(&self, df: DataFrame) -> FeatureFactoryResult<DataFrame>
Transform validates that each target column is numeric and that the intervals are valid, then applies the interval mapping.