pub struct MathFeatures {
pub features: Vec<(String, Expr)>,
}Expand description
Creates new features using arbitrary mathematical operations or expressions. The input is a vector of tuples with the following fields for each new feature: (new_feature_name, math expression to be computed).
Fields
features: Vec<(String, Expr)>Implementations
Sourceimpl MathFeatures
impl MathFeatures
pub fn new(features: Vec<(String, Expr)>) -> Self
Sourcepub async fn fit(&mut self, _df: &DataFrame) -> FeatureFactoryResult<()>
pub async fn fit(&mut self, _df: &DataFrame) -> FeatureFactoryResult<()>
Stateless transformer: fit does nothing.
Sourcepub fn transform(&self, df: DataFrame) -> FeatureFactoryResult<DataFrame>
pub fn transform(&self, df: DataFrame) -> FeatureFactoryResult<DataFrame>
Adds the new features to the existing DataFrame.