pub struct RelativeFeatures {
pub features: Vec<(String, String, String, RelativeOperation)>,
}Expand description
Creates new features by combining a target feature with a reference feature. Input is a vector of tuples with the following fields for each new feature: (new_feature_name, target_feature, reference_feature, operation).
Fields
features: Vec<(String, String, String, RelativeOperation)>Implementations
Sourceimpl RelativeFeatures
impl RelativeFeatures
pub fn new(features: Vec<(String, String, String, RelativeOperation)>) -> Self
Sourcepub async fn fit(&mut self, _df: &DataFrame) -> FeatureFactoryResult<()>
pub async fn fit(&mut self, _df: &DataFrame) -> FeatureFactoryResult<()>
Stateless transformer: fit does nothing.
Sourcepub fn transform(&self, df: DataFrame) -> FeatureFactoryResult<DataFrame>
pub fn transform(&self, df: DataFrame) -> FeatureFactoryResult<DataFrame>
Adds the relative features to the DataFrame.