pub struct SelectBySingleFeaturePerformance {
pub target: String,
pub correlation_threshold: f64,
pub selected_features: HashSet<String>,
/* private fields */
}Expand description
Selects numeric features based on absolute correlation with a binary target. Note: To preserve order between feature and target values, this transformer uses sequential iterators so it may be relatively slow.
Fields
target: Stringcorrelation_threshold: f64selected_features: HashSet<String>Implementations