pub struct DropMissingData {
pub columns: Option<Vec<String>>,
}Expand description
Removes rows that contain a missing value in the given columns.
Fields
columns: Option<Vec<String>>Optional list of column names to check for missing values. If None, all columns in the DataFrame are checked.
Implementations
Sourceimpl DropMissingData
impl DropMissingData
pub fn new() -> Self
pub fn with_columns(columns: Vec<String>) -> Self
Sourcepub async fn fit(&mut self, _df: &DataFrame) -> FeatureFactoryResult<()>
pub async fn fit(&mut self, _df: &DataFrame) -> FeatureFactoryResult<()>
Stateless transformer: fit does nothing.
Sourcepub fn transform(&self, df: DataFrame) -> FeatureFactoryResult<DataFrame>
pub fn transform(&self, df: DataFrame) -> FeatureFactoryResult<DataFrame>
Transform applies filtering and returns the modified DataFrame.